# NameV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV20**](CreatedDateV20.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV20**](LastModifiedDateV20.md) |  | [optional] 
**given_names** | [**GivenNamesV20**](GivenNamesV20.md) |  | [optional] 
**family_name** | [**FamilyNameV20**](FamilyNameV20.md) |  | [optional] 
**credit_name** | [**CreditNameV20**](CreditNameV20.md) |  | [optional] 
**source** | [**SourceV20**](SourceV20.md) |  | [optional] 
**visibility** | **str** |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

